BenchmarkPlan

Struct BenchmarkPlan 

pub struct BenchmarkPlan { /* private fields */ }
Bounded benchmark execution plan.

Implementations

Source

impl BenchmarkPlan

pub const fn new(measured_runs: NonZeroUsize) -> Self

Creates a sequential plan with no warmup.

pub const fn with_warmup(self, warmup_runs: usize) -> Self

Adds unmeasured warmup invocations.

pub const fn with_concurrency(self, concurrency: NonZeroUsize) -> Self

Bounds concurrently executing measured invocations.

pub fn with_environment( self, key: impl Into<String>, value: impl Into<String>, ) -> Self

Records one stable environment fact in the generated report.

Use this for framework version, Rust toolchain, target, runtime, hardware class, provider endpoint, and model revision.