BenchmarkTarget

Trait BenchmarkTarget 

pub trait BenchmarkTarget: Send + Sync {
    // Required method
    fn execute(&self) -> BenchmarkFuture<'_>;
}
Framework-neutral operation executed by the benchmark runner.

External comparison adapters can implement this trait for another runtime, including Rig, while retaining identical scheduling and report semantics.

Required Methods

fn execute(&self) -> BenchmarkFuture<'_>

Executes one isolated invocation.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors